!-----------------------BEGIN NOTICE -- DO NOT EDIT-----------------------
! NASA Goddard Space Flight Center Land Information System (LIS) v7.1
!
! Copyright (c) 2015 United States Government as represented by the
! Administrator of the National Aeronautics and Space Administration.
! All Rights Reserved.
!-------------------------END NOTICE -- DO NOT EDIT-----------------------
module LIS_PEobs_pluginMod
!BOP
!
! !MODULE: LIS_PEobs_pluginMod
! 
! !DESCRIPTION: 
!   This module contains the definition of the functions that are
!   used to read observation data that constitute the observation space
!   for parameter estimation. 
!   The user defined functions are incorporated into 
!   the appropriate registry to be later invoked through generic calls. 
!   
! !REVISION HISTORY: 
!  16 Jul 2009;   Sujay Kumar  Initial Specification
! 
!EOP  
  implicit none
  PRIVATE
!------------------------------------------------------------------------------
! !PUBLIC MEMBER FUNCTIONS:
!------------------------------------------------------------------------------
  PUBLIC :: LIS_PEobs_plugin    
contains
!BOP
! !ROUTINE: LIS_PEobs_plugin
!  \label{LIS_PEobs_plugin}
!
! !DESCRIPTION:
!
!  This is a plugin point for introducing routines to handle the 
!  data that constitute the observation space for parameter estimation. 
!
! !INTERFACE:
  subroutine LIS_PEobs_plugin
!EOP

    use LIS_pluginIndices
#if 0
    use templateObs_module, only : templateObs_setup
    use pesynsm1data_module, only : pesynsm1data_setup
    use ISCCP_Tskinobs_module, only : ISCCP_Tskinobs_setup
    use wgPBMRsmobs_module, only : wgPBMRsmdata_setup
    use MaconLSDataMod, only : maconlsobs_setup
    use GlobalLSDataMod, only : globallsobs_setup
    use AmerifluxObsMod,     only : Amerifluxobs_setup
    use CNRS_em_obsMod, only : CNRS_em_obs_setup
    use USDA_ARSsm_obsMod, only : USDA_ARSsm_obs_setup
#endif
    use AMSRE_SR_em_obsMod, only : AMSRE_SR_em_obs_setup
    use LPRM_AMSREsm_obsMod, only : LPRM_AMSREsm_obs_setup
#if 0
    use ARMdata_module,      only : ARMdata_setup
    use FLUXNETdata_module,  only : FLUXNETdata_setup
#endif

    use Empty_obsMod

#if 0
    external read_templateObs, write_templateObs, reset_templateObs
    external read_pesynsm1data
    external read_wgPBMRsmdata, write_wgPBMRsmdata, reset_wgPBMRsmdata
    external read_ISCCP_Tskindata
    external read_MaconLSObsdata, write_MaconLSObsdata
    external read_GlobalLSObsdata, write_GlobalLSObsdata, reset_globallsObsdata
    external read_AmerifluxObs, write_AmerifluxObs
    external read_CNRS_em_obsdata, write_CNRS_em_obs_data,reset_CNRS_em_obs_data
    external read_USDA_ARSsm_obsdata, write_USDA_ARS_sm_obs_data,reset_USDA_ARSsm_obs_data
#endif
    external read_AMSRE_SR_em_obsdata, write_AMSRE_SR_em_obs_data,reset_AMSRE_SR_em_obs_data
#if 0
    external read_CNRS_MPDI_em_obsdata
    external read_ARMdata, write_ARMdata, reset_ARMdata
#endif
    external read_LPRM_AMSREsm_obsdata, write_LPRM_AMSREsm_obs_data,reset_LPRM_AMSREsm_obs_data
#if 0
    external read_FLUXNETdata, write_FLUXNETdata, reset_FLUXNETdata
#endif

#if 0
    call registerpeobssetup(trim(LIS_templateObsId)//char(0),templateObs_setup)
    call registergetpeobs(trim(LIS_templateObsId)//char(0),read_templateObs)
    call registerwritepeobs(trim(LIS_templateObsId)//char(0),write_templateObs)
    call registerpeobsreset(trim(LIS_templateObsId)//char(0),reset_templateObs)

    call registerpeobssetup(trim(LIS_pesynsm1Id)//char(0),pesynsm1data_setup)
    call registergetpeobs(trim(LIS_pesynsm1Id)//char(0),read_pesynsm1data)

    call registerpeobssetup(trim(LIS_wgPBMRsmId)//char(0),wgPBMRsmdata_setup)
    call registergetpeobs(trim(LIS_wgPBMRsmId)//char(0),read_wgPBMRsmdata)
    call registerwritepeobs(trim(LIS_wgPBMRsmId)//char(0),write_wgPBMRsmdata)
    call registerpeobsreset(trim(LIS_wgPBMRsmId)//char(0), reset_wgPBMRsmdata)

    call registerpeobssetup(trim(LIS_pesynsm2Id)//char(0),pesynsm1data_setup)
    call registergetpeobs(trim(LIS_pesynsm2Id)//char(0),read_pesynsm1data)

    call registerpeobssetup(trim(LIS_isccpTskinId)//char(0),ISCCP_Tskinobs_setup)
    call registergetpeobs(trim(LIS_isccpTskinId)//char(0),read_ISCCP_Tskindata)

    call registerpeobssetup(trim(LIS_maconlandslideObsId)//char(0),maconlsobs_setup)
    call registergetpeobs(trim(LIS_maconlandslideObsId)//char(0),read_maconlsObsdata)
    call registerwritepeobs(trim(LIS_maconlandslideObsId)//char(0),write_maconlsObsdata)

    call registerpeobssetup(trim(LIS_globallandslideObsId)//char(0),globallsobs_setup)
    call registergetpeobs(trim(LIS_globallandslideObsId)//char(0),read_globallsObsdata)
    call registerwritepeobs(trim(LIS_globallandslideObsId)//char(0),write_globallsObsdata)
    call registerpeobsreset(trim(LIS_globallandslideObsId)//char(0),reset_globallsObsdata)

    call registerpeobssetup(trim(LIS_AmerifluxObsId)//char(0),AmerifluxObs_setup)
    call registergetpeobs(trim(LIS_AmerifluxObsId)//char(0),read_AmerifluxObs)
    call registerwritepeobs(trim(LIS_AmerifluxObsId)//char(0),write_AmerifluxObs)

    call registerpeobssetup(trim(LIS_CNRSObsId)//char(0),CNRS_em_obs_setup)
    call registergetpeobs(trim(LIS_CNRSObsId)//char(0),read_CNRS_em_obsdata)
    call registerwritepeobs(trim(LIS_CNRSObsId)//char(0),write_CNRS_em_obs_data)
    call registerpeobsreset(trim(LIS_CNRSObsId)//char(0),reset_CNRS_em_obs_data)

    call registerpeobssetup(trim(LIS_CNRS_MPDIObsId)//char(0),CNRS_em_obs_setup)
    call registergetpeobs(trim(LIS_CNRS_MPDIObsId)//char(0),read_CNRS_MPDI_em_obsdata)
    call registerwritepeobs(trim(LIS_CNRS_MPDIObsId)//char(0),write_CNRS_em_obs_data)
    call registerpeobsreset(trim(LIS_CNRS_MPDIObsId)//char(0),reset_CNRS_em_obs_data)
#endif

    call registerpeobssetup(trim(LIS_AMSRE_SRObsId)//char(0),AMSRE_SR_em_obs_setup)
    call registergetpeobs(trim(LIS_AMSRE_SRObsId)//char(0),read_AMSRE_SR_em_obsdata)
    call registerwritepeobs(trim(LIS_AMSRE_SRObsId)//char(0),write_AMSRE_SR_em_obs_data)
    call registerpeobsreset(trim(LIS_AMSRE_SRObsId)//char(0),reset_AMSRE_SR_em_obs_data)

    call registerpeobssetup(trim(LIS_LPRM_AMSREsmpeObsId)//char(0),LPRM_AMSREsm_obs_setup)
    call registergetpeobs(trim(LIS_LPRM_AMSREsmpeObsId)//char(0),read_LPRM_AMSREsm_obsdata)
    call registerwritepeobs(trim(LIS_LPRM_AMSREsmpeObsId)//char(0),write_LPRM_AMSREsm_obs_data)
    call registerpeobsreset(trim(LIS_LPRM_AMSREsmpeObsId)//char(0),reset_LPRM_AMSREsm_obs_data)

#if 0
    call registerpeobssetup(trim(LIS_FLUXNETpeObsId)//char(0),FLUXNETdata_setup)
    call registergetpeobs(trim(LIS_FLUXNETpeObsId)//char(0),read_FLUXNETdata)
    call registerwritepeobs(trim(LIS_FLUXNETpeObsId)//char(0),write_FLUXNETdata)
    call registerpeobsreset(trim(LIS_FLUXNETpeObsId)//char(0),reset_FLUXNETdata)
#endif

    call registerpeobssetup(trim(LIS_EmptyObsId)//char(0),Empty_obs_setup)
    call registergetpeobs(trim(LIS_EmptyObsId)//char(0),read_Empty_em_obsdata)
    call registerwritepeobs(trim(LIS_EmptyObsId)//char(0),write_EmptyObsdata)

#if 0
    call registerpeobssetup(trim(LIS_ARMObsId)//char(0),ARMdata_setup)
    call registergetpeobs(trim(LIS_ARMObsId)//char(0),read_ARMdata)
    call registerwritepeobs(trim(LIS_ARMObsId)//char(0),write_ARMdata)
    call registerpeobsreset(trim(LIS_ARMObsId)//char(0),reset_ARMdata)

    call registerpeobssetup(trim(LIS_USDA_ARSsmpeObsId)//char(0),USDA_ARSsm_obs_setup)
    call registergetpeobs(trim(LIS_USDA_ARSsmpeObsId)//char(0),read_USDA_ARSsm_obsdata)
    call registerwritepeobs(trim(LIS_USDA_ARSsmpeObsId)//char(0),write_USDA_ARS_sm_obs_data)
    call registerpeobsreset(trim(LIS_USDA_ARSsmpeObsId)//char(0),reset_USDA_ARSsm_obs_data)
#endif

  end subroutine LIS_PEobs_plugin
end module LIS_PEobs_pluginMod
