!-----------------------BEGIN NOTICE -- DO NOT EDIT-----------------------
! NASA Goddard Space Flight Center Land Information System (LIS) v7.1
!
! Copyright (c) 2015 United States Government as represented by the
! Administrator of the National Aeronautics and Space Administration.
! All Rights Reserved.
!-------------------------END NOTICE -- DO NOT EDIT-----------------------
module LIS_routing_pluginMod
!BOP
!
! !MODULE: LIS_routing_pluginMod
! 
! !DESCRIPTION: 
!   This module contains the definition of the functions used for
!   routing model initialization, execution, reading and 
!   writing of restart files and other relevant routing
!   model computations. 
!   
! !REVISION HISTORY: 
!  6 May 11    Sujay Kumar  Initial Specification
! 
!EOP  
  implicit none
  PRIVATE
!------------------------------------------------------------------------------
! !PUBLIC MEMBER FUNCTIONS:
!------------------------------------------------------------------------------
  PUBLIC :: LIS_routing_plugin  
  
contains
!BOP
! !ROUTINE: LIS_routing_plugin
!  \label{LIS_routing_plugin}
!
! !DESCRIPTION:
!
! This is a custom-defined plugin point for introducing a new routing scheme. 
! The interface mandates that the following routines be implemented
! and registered for each of the routing scheme that is included in LIS. 
!

! !INTERFACE:
  subroutine LIS_routing_plugin
!EOP

    use LIS_pluginIndices
    use NLDAS_routingMod, only : NLDAS_routingInit
    use HYMAP_routingMod, only : HYMAP_routingInit

    implicit none

    external NLDAS_routing_readrst
    external NLDAS_routing_run
    external NLDAS_routing_output
    external NLDAS_routing_writerst

    external HYMAP_routing_readrst
    external HYMAP_routing_run
    external HYMAP_routing_output
    external HYMAP_routing_writerst

    call registerroutinginit(trim(LIS_NLDASrouterId)//char(0), &
         NLDAS_routingInit)
    call registerroutingreadrestart(trim(LIS_NLDASrouterId)//char(0), &
         NLDAS_routing_readrst)
    call registerroutingrun(trim(LIS_NLDASrouterId)//char(0), &
         NLDAS_routing_run)
    call registerroutingoutput(trim(LIS_NLDASrouterId)//char(0), &
         NLDAS_routing_output)
    call registerroutingwriterestart(trim(LIS_NLDASrouterId)//char(0), &
         NLDAS_routing_writerst)


    call registerroutinginit(trim(LIS_HYMAProuterId)//char(0), &
         HYMAP_routingInit)
    call registerroutingreadrestart(trim(LIS_HYMAProuterId)//char(0), &
         HYMAP_routing_readrst)
    call registerroutingrun(trim(LIS_HYMAProuterId)//char(0), &
         HYMAP_routing_run)
    call registerroutingoutput(trim(LIS_HYMAProuterId)//char(0), &
         HYMAP_routing_output)
    call registerroutingwriterestart(trim(LIS_HYMAProuterId)//char(0), &
         HYMAP_routing_writerst)


  end subroutine LIS_routing_plugin

end module LIS_routing_pluginMod
