!-----------------------BEGIN NOTICE -- DO NOT EDIT-----------------------
! NASA Goddard Space Flight Center Land Information System (LIS) v7.1
!
! Copyright (c) 2015 United States Government as represented by the
! Administrator of the National Aeronautics and Space Administration.
! All Rights Reserved.
!-------------------------END NOTICE -- DO NOT EDIT-----------------------
!BOP
! !ROUTINE: clsmf25_gettwspred
! \label{clsmf25_gettwspred}
!
! !REVISION HISTORY:
! 27Feb2005: Sujay Kumar; Initial Specification
! 25Jun2006: Sujay Kumar: Updated for the ESMF design
! 28Sep2011: Ben Zaitchik: Applied to GRACE
!
! !INTERFACE:
subroutine clsmf25_gettwspred(n,obs_pred)
! !USES:
  use ESMF
  use LIS_coreMod, only : LIS_rc,LIS_surface
  use clsmf25_lsmMod
  use LIS_logMod, only : LIS_logunit, LIS_verify
  use clsmf25_tws_DAlogMod, only : CLSMpred_struc
        
!EOP

  implicit none
! !ARGUMENTS: 
  integer, intent(in)    :: n
!  real                   :: clmnwater(3,LIS_rc%ngrid(n),LIS_rc%nensem(n))
  real                   :: obs_pred(LIS_rc%ngrid(n),LIS_rc%nensem(n))
  integer                :: count1(LIS_rc%ngrid(n),LIS_rc%nensem(n))
!
! !DESCRIPTION:
!
!  Returns the TWS obs pred (model's estimate of 
!  observations) for data assimilation
! 
!  The arguments are: 
!  \begin{description}
!  \item[n] index of the nest \newline
!  \item[obs\_pred] model's estimate of observations \newline
!  \end{description}
!EOP
  integer                :: i,t,m,gid

  obs_pred = 0.0
  count1 = 0.0 
  do i=1,LIS_rc%npatch(n,LIS_rc%lsm_index),LIS_rc%nensem(n)
     do m=1,LIS_rc%nensem(n)
        t = i+m-1
        gid = LIS_surface(n,LIS_rc%lsm_index)%tile(t)%index        
        obs_pred(gid,m)= obs_pred(gid,m)+ (CLSMpred_struc(n)%clmnwater(1,gid,m) + &	
	 CLSMpred_struc(n)%clmnwater(2,gid,m)+CLSMpred_struc(n)%clmnwater(3,gid,m))/3.	
        count1(gid,m) = count1(gid,m) +1
     enddo
  enddo
   
  do i=1,LIS_rc%ngrid(n)
     do m=1,LIS_rc%nensem(n)
        obs_pred(i,m) = obs_pred(i,m)/(count1(i,m))
     enddo
  enddo

end subroutine clsmf25_gettwspred

